(function( $ ) {
	'use strict';

	// Create the defaults once
	var pluginName = "WooCommerceUltimatePricing",
		defaults = {
			'modalHeightAuto' : '1',
		};

	// The actual plugin constructor
	function Plugin ( element, options ) {
		this.element = element;
		
		this.settings = $.extend( {}, defaults, options );
		this._defaults = defaults;
		this.trans = this.settings.trans;
		this._name = pluginName;
		this.init();
	}

	// Avoid Plugin.prototype conflicts
	$.extend( Plugin.prototype, {
		init: function() {
			this.window = $(window);
			this.documentHeight = $( document ).height();
			this.windowHeight = this.window.height();
			this.product = {};
			this.elements = {};

			this.tieredPricing();
		},
		tieredPricing : function() {

			var that = this;
			if(that.settings.tiered_pricing == "0") {
				return;
			}

			var tieredPricingTable = $('.woocommerce-ultimate-pricing-tiered-pricing-table');
			if(tieredPricingTable.length < 1) {
				return;
			}

			if(that.settings.wc_decimal_num.length > 0) {
				var priceDecimals = that.settings.wc_decimal_seperator + that.settings.wc_decimal_num;
			} else {
				var priceDecimals = '';
			}

			var priceField = $('.price:not(.price-unit)').first();
			var originalPrice = priceField.html();
			var tieredPrice = 0;
			var tieredType = tieredPricingTable.data('type');
			var variationsForm = $('.variations_form');
			var variationPriceField, variationOriginalPrice, variationOriginalPriceHtml, variationPrice;

			$(document).on('change', '[name="quantity"]', function(e) {
				var $this = $(this);
				var quantity = $this.val();
				
				tieredPrice = 0;
				tieredPricingTable.find('tbody tr').each(function(i, index) {
					var tieredPricingRow = $(this);
					var minQuantity = parseInt( tieredPricingRow.data('min-quantity') );
					var maxQuantity = parseInt( tieredPricingRow.data('max-quantity') );
					var price = tieredPricingRow.data('price');
					

					if(quantity >= minQuantity && quantity <= maxQuantity) {
						tieredPricingRow.addClass('woocommerce-ultimate-pricing-tiered-pricing-table-row-active');
						tieredPrice = price;
					} else {
						tieredPricingRow.removeClass('woocommerce-ultimate-pricing-tiered-pricing-table-row-active');
					}
					
				});

				if(variationsForm.length < 1) {

					if(tieredPrice.length > 0) {

						tieredPrice = tieredPrice;
						// tieredPrice = tieredPrice.replace( '.',  that.settings.wc_decimal_seperator);
						priceField.html( that.settings.price_template.replace('0' + priceDecimals, tieredPrice) );
					} else {
						priceField.html( originalPrice );
					}

				} else {

					variationPriceField = $('.woocommerce-variation-price .price');
					if(variationPriceField.length < 1) {
						return;
					}

					if(!variationPrice) {
						variationOriginalPriceHtml = variationPriceField.html();
						variationPrice = variationOriginalPriceHtml.match(/\b\d+(?:.\d+)?/);
					}
					
					var activeTieredPrice = tieredPricingTable.find('.woocommerce-ultimate-pricing-tiered-pricing-table-row-active');
					if(activeTieredPrice.length < 1) {
						variationPriceField.html(variationOriginalPriceHtml);
						return;
					}

					var tieredDiscount = activeTieredPrice.data('discount');
					// var variationPrice = variation.display_price;
					var tieredPrice;
					if(tieredType == "percentage") {
						tieredPrice = variationPrice - (variationPrice * (tieredDiscount / 100));
					} else {
						tieredPrice = variationPrice - tieredDiscount;
					}
					
					if(tieredPrice.length > 0) {
						tieredPrice = tieredPrice;
						// tieredPrice = tieredPrice.replace( '.',  that.settings.wc_decimal_seperator);
						variationPriceField.html( that.settings.price_template.replace('0' + priceDecimals, tieredPrice) );
					} else {
						variationPriceField.html(variationOriginalPriceHtml);
					}
				}
			}).trigger('change');

			$(document).on('click', '.woocommerce-ultimate-pricing-tiered-pricing-table tr', function(e) {
				var $this = $(this);
				var minQuantity = parseInt( $this.data('min-quantity') );
				$('[name="quantity"]').val( minQuantity ).trigger('change');
			});

			
			if(variationsForm.length > 0) {

				

				$(variationsForm).on('found_variation', function(e, variation) {
					variationPrice = false;
				});
			}
			
		},
	} );

	// Constructor wrapper
	$.fn[ pluginName ] = function( options ) {
		return this.each( function() {
			if ( !$.data( this, "plugin_" + pluginName ) ) {
				$.data( this, "plugin_" +
					pluginName, new Plugin( this, options ) );
			}
		} );
	};

	$(document).ready(function() {

		$( "body" ).WooCommerceUltimatePricing( 
			woocommerce_ultimate_pricing_options
		);

	} );

})( jQuery );